@@ -23,7 +23,7 @@ COLUMNS = [
         mask="storageType.keyName"),
     column_helper.Column('capacity_gb', ('capacityGb',), mask="capacityGb"),
     column_helper.Column('bytes_used', ('bytesUsed',), mask="bytesUsed"),
-    column_helper.Column('iops', ('iops',), mask="iops"),
+    column_helper.Column('IOPs', ('provisionedIops',), mask="provisionedIops"),
     column_helper.Column('ip_addr', ('serviceResourceBackendIpAddress',),
                          mask="serviceResourceBackendIpAddress"),
     column_helper.Column('lunId', ('lunId',), mask="lunId"),
@@ -44,7 +44,7 @@ DEFAULT_COLUMNS = [
     'storage_type',
     'capacity_gb',
     'bytes_used',
-    'iops',
+    'IOPs',
     'ip_addr',
     'lunId',
     'active_transactions',
