@@ -23,9 +23,9 @@ def cli(env, identifier):
     instance = manager.get_hardware(hardware_id)
 
     table = formatting.Table(['username', 'password'])
-    if 'passwords' not in instance['operatingSystem']:
-        raise exceptions.SoftLayerError("No passwords found in operatingSystem")
-
-    for item in instance['operatingSystem']['passwords']:
-        table.add_row([item.get('username', 'None'), item.get('password', 'None')])
+    for item in instance['softwareComponents']:
+        if 'passwords' not in item:
+            raise exceptions.SoftLayerError("No passwords found in softwareComponents")
+        for credentials in item['passwords']:
+            table.add_row([credentials.get('username', 'None'), credentials.get('password', 'None')])
     env.fout(table)
