@@ -16,8 +16,10 @@ from SoftLayer.CLI import helpers
               default=None,
               help="The IBM Cloud API Key with access to IBM Cloud Object "
                    "Storage instance. For help creating this key see "
-                   "https://console.bluemix.net/docs/services/cloud-object-"
-                   "storage/iam/users-serviceids.html#serviceidapikeys")
+                   "https://cloud.ibm.com/docs/cloud-object-storage?"
+                   "topic=cloud-object-storage-iam-overview#iam-overview"
+                   "-service-id-api-key "
+              )
 @environment.pass_env
 def cli(env, identifier, uri, ibm_api_key):
     """Export an image to object storage.
