@@ -92,6 +92,7 @@ ALL_ROUTES = [
     ('block:subnets-remove', 'SoftLayer.CLI.block.subnets.remove:cli'),
     ('block:replica-failback', 'SoftLayer.CLI.block.replication.failback:cli'),
     ('block:replica-failover', 'SoftLayer.CLI.block.replication.failover:cli'),
+    ('block:disaster-recovery-failover', 'SoftLayer.CLI.block.replication.disaster_recovery_failover:cli'),
     ('block:replica-order', 'SoftLayer.CLI.block.replication.order:cli'),
     ('block:replica-partners', 'SoftLayer.CLI.block.replication.partners:cli'),
     ('block:replica-locations', 'SoftLayer.CLI.block.replication.locations:cli'),
@@ -127,6 +128,7 @@ ALL_ROUTES = [
     ('file:access-revoke', 'SoftLayer.CLI.file.access.revoke:cli'),
     ('file:replica-failback', 'SoftLayer.CLI.file.replication.failback:cli'),
     ('file:replica-failover', 'SoftLayer.CLI.file.replication.failover:cli'),
+    ('file:disaster-recovery-failover', 'SoftLayer.CLI.file.replication.disaster_recovery_failover:cli'),
     ('file:replica-order', 'SoftLayer.CLI.file.replication.order:cli'),
     ('file:replica-partners', 'SoftLayer.CLI.file.replication.partners:cli'),
     ('file:replica-locations', 'SoftLayer.CLI.file.replication.locations:cli'),
