@@ -8,6 +8,8 @@ from SoftLayer.CLI import columns as column_helper
 from SoftLayer.CLI import environment
 from SoftLayer.CLI import formatting
 
+TWO_FACTO_AUTH = 'externalBindingCount'
+CLASSIC_API_KEYS = 'apiAuthenticationKeyCount'
 
 COLUMNS = [
     column_helper.Column('id', ('id',)),
@@ -16,14 +18,18 @@ COLUMNS = [
     column_helper.Column('displayName', ('displayName',)),
     column_helper.Column('status', ('userStatus', 'name')),
     column_helper.Column('hardwareCount', ('hardwareCount',)),
-    column_helper.Column('virtualGuestCount', ('virtualGuestCount',))
+    column_helper.Column('virtualGuestCount', ('virtualGuestCount',)),
+    column_helper.Column('2FA', (TWO_FACTO_AUTH,)),
+    column_helper.Column('classicAPIKey', (CLASSIC_API_KEYS,))
 ]
 
 DEFAULT_COLUMNS = [
     'id',
     'username',
     'email',
-    'displayName'
+    'displayName',
+    '2FA',
+    'classicAPIKey',
 ]
 
 
@@ -42,7 +48,16 @@ def cli(env, columns):
 
     table = formatting.Table(columns.columns)
     for user in users:
+        user = _yes_format(user, [TWO_FACTO_AUTH, CLASSIC_API_KEYS])
         table.add_row([value or formatting.blank()
                        for value in columns.row(user)])
 
     env.fout(table)
+
+
+def _yes_format(user, keys):
+    """Changes all dictionary values to yes whose keys are in the list. """
+    for key in keys:
+        if user.get(key):
+            user[key] = 'yes'
+    return user
