@@ -9,6 +9,7 @@ import SoftLayer
 from SoftLayer.CLI import environment
 from SoftLayer.CLI import formatting
 from SoftLayer.CLI import helpers
+from SoftLayer.CLI.virt.storage import get_local_storage_table
 from SoftLayer import utils
 
 LOGGER = logging.getLogger(__name__)
@@ -34,11 +35,7 @@ def cli(env, identifier, passwords=False, price=False):
     result = utils.NestedDict(result)
     local_disks = vsi.get_local_disks(vs_id)
 
-    table_local_disks = formatting.Table(['Type', 'Name', 'Capacity'])
-    for disks in local_disks:
-        if 'diskImage' in disks:
-            table_local_disks.add_row([get_local_type(disks), disks['mountType'],
-                                       str(disks['diskImage']['capacity']) + " " + str(disks['diskImage']['units'])])
+    table_local_disks = get_local_storage_table(local_disks)
 
     table.add_row(['id', result['id']])
     table.add_row(['guid', result['globalIdentifier']])
@@ -172,7 +169,7 @@ def _get_owner_row(result):
         owner = utils.lookup(result, 'billingItem', 'orderItem', 'order', 'userRecord', 'username')
     else:
         owner = formatting.blank()
-    return(['owner', owner])
+    return (['owner', owner])
 
 
 def _get_vlan_table(result):
@@ -200,15 +197,3 @@ def _get_security_table(result):
         return secgroup_table
     else:
         return None
-
-
-def get_local_type(disks):
-    """Returns the virtual server local disk type.
-
-    :param disks: virtual serve local disks.
-    """
-    disk_type = 'System'
-    if 'SWAP' in disks['diskImage']['description']:
-        disk_type = 'Swap'
-
-    return disk_type
