@@ -6,6 +6,9 @@
     :license: MIT, see LICENSE for more details.
 """
 
+from SoftLayer.exceptions import SoftLayerError
+from SoftLayer import utils
+
 LIST_ACCOUNTS_MASK = '''mask[
     id,username,notes,vendorName,serviceResource
 ]'''
@@ -15,7 +18,7 @@ ENDPOINT_MASK = '''mask(SoftLayer_Network_Storage_Hub_Swift)[
 ]'''
 
 
-class ObjectStorageManager(object):
+class ObjectStorageManager(utils.IdentifierMixin, object):
     """Manager for SoftLayer Object Storage accounts.
 
     See product information here: https://www.ibm.com/cloud/object-storage
@@ -26,11 +29,16 @@ class ObjectStorageManager(object):
 
     def __init__(self, client):
         self.client = client
+        self.resolvers = [self._get_id_from_username]
 
-    def list_accounts(self):
+    def list_accounts(self, object_mask=None, object_filter=None, limit=10):
         """Lists your object storage accounts."""
-        return self.client.call('Account', 'getHubNetworkStorage',
-                                mask=LIST_ACCOUNTS_MASK)
+        object_mask = object_mask if object_mask else LIST_ACCOUNTS_MASK
+        return self.client.call('Account',
+                                'getHubNetworkStorage',
+                                mask=object_mask,
+                                filter=object_filter,
+                                limit=limit)
 
     def list_endpoints(self):
         """Lists the known object storage endpoints."""
@@ -96,3 +104,19 @@ class ObjectStorageManager(object):
 
         return self.client.call('SoftLayer_Network_Storage_Hub_Cleversafe_Account', 'getCredentials',
                                 id=identifier)
+
+    def _get_id_from_username(self, username):
+        """Looks up a username's id
+
+        :param string username: Username to lookup
+        :returns: The id that matches username.
+        """
+        _mask = "mask[id,username]"
+        _filter = {'hubNetworkStorage': {'username': utils.query_filter(username)}}
+        account = self.list_accounts(_mask, _filter)
+        if len(account) == 1:
+            return [account[0]['id']]
+        elif len(account) > 1:
+            raise SoftLayerError("Multiple object storage accounts found with the name: {}".format(username))
+        else:
+            raise SoftLayerError("Unable to find object storage account id for: {}".format(username))
