@@ -533,10 +533,11 @@ class VSManager(utils.IdentifierMixin, object):
         if datacenter:
             data["datacenter"] = {"name": datacenter}
 
-        if private_vlan or public_vlan or private_subnet or public_subnet:
-            network_components = self._create_network_components(public_vlan, private_vlan,
-                                                                 private_subnet, public_subnet)
-            data.update(network_components)
+        network_components = self._create_network_components(public_vlan, private_vlan,
+                                                             private_subnet, public_subnet,
+                                                             kwargs.get('private_router'),
+                                                             kwargs.get('public_router'))
+        data.update(network_components)
 
         if public_security_groups:
             secgroups = [{'securityGroup': {'id': int(sg)}}
@@ -581,8 +582,17 @@ class VSManager(utils.IdentifierMixin, object):
 
     def _create_network_components(
             self, public_vlan=None, private_vlan=None,
-            private_subnet=None, public_subnet=None):
+            private_subnet=None, public_subnet=None,
+            private_router=None, public_router=None):
         parameters = {}
+        if any([private_router, public_router]) and any([private_vlan, public_vlan, private_subnet, public_subnet]):
+            raise exceptions.SoftLayerError("You have to select network vlan or network vlan with a subnet or "
+                                            "only router, not all options")
+
+        if private_router:
+            parameters['primaryBackendNetworkComponent'] = {"router": {"id": int(private_router)}}
+        if public_router:
+            parameters['primaryNetworkComponent'] = {"router": {"id": int(public_router)}}
         if private_vlan:
             parameters['primaryBackendNetworkComponent'] = {"networkVlan": {"id": int(private_vlan)}}
         if public_vlan:
@@ -685,7 +695,21 @@ class VSManager(utils.IdentifierMixin, object):
         kwargs.pop('tags', None)
         create_options = self._generate_create_dict(**kwargs)
         template = self.guest.generateOrderTemplate(create_options)
-        if 'private_subnet' in kwargs or 'public_subnet' in kwargs:
+        if kwargs.get('public_router') or kwargs.get('private_router'):
+            if kwargs.get('private_vlan') or kwargs.get('public_vlan') or kwargs.get('private_subnet') \
+                    or kwargs.get('public_subnet'):
+                raise exceptions.SoftLayerError("You have to select network vlan or network vlan with a subnet or "
+                                                "only router, not all options")
+            vsi = template['virtualGuests'][0]
+            network_components = self._create_network_components(kwargs.get('public_vlan', None),
+                                                                 kwargs.get('private_vlan', None),
+                                                                 kwargs.get('private_subnet', None),
+                                                                 kwargs.get('public_subnet', None),
+                                                                 kwargs.get('private_router', None),
+                                                                 kwargs.get('public_router', None))
+            vsi.update(network_components)
+
+        if kwargs.get('private_subnet') or kwargs.get('public_subnet'):
             vsi = template['virtualGuests'][0]
             network_components = self._create_network_components(kwargs.get('public_vlan', None),
                                                                  kwargs.get('private_vlan', None),
